@@ -30,9 +30,9 @@ from shapely.geometry import LineString
 import itertools
 import numpy
 # mine
-import hwrt.HandwrittenData as HandwrittenData
-import hwrt.preprocessing as preprocessing
-import hwrt.utils as utils
+import HandwrittenData
+import preprocessing
+import utils
 
 
 def get_class(name):
