@@ -27,8 +27,8 @@ logging.basicConfig(format='%(asctime)s %(levelname)s %(message)s',
                     level=logging.DEBUG,
                     stream=sys.stdout)
 # mine
-import hwrt.HandwrittenData as HandwrittenData
-import hwrt.utils as utils
+import HandwrittenData
+import utils
 
 
 def _euclidean_distance(p1, p2):
